# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['giphpy']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.22.0,<0.23.0',
 'pydantic>=1.9.0,<2.0.0',
 'typing-extensions>=4.2.0,<5.0.0']

setup_kwargs = {
    'name': 'giphpy',
    'version': '0.1.0',
    'description': 'a better python GIPHY client',
    'long_description': '[![test](https://github.com/zschumacher/giphpy/actions/workflows/test.yml/badge.svg)](https://github.com/zschumacher/giphpy/actions/workflows/test.yml)\n[![Documentation Status](https://readthedocs.org/projects/giphpy/badge/?version=latest)](https://giphpy.readthedocs.io/en/latest/?badge=latest)\n[![codecov](https://codecov.io/gh/zschumacher/giphpy/branch/main/graph/badge.svg?token=ADXWQI8YMX)](https://codecov.io/gh/zschumacher/giphpy)\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)\n\n# giphpy\n`giphpy` was written to be a hand-spun alternative to the existing [GIPHY client](https://github.com/Giphy/giphy-python-client).\n\nYou should use it because:\n\n* it uses [pydantic](https://pydantic-docs.helpmanual.io) for lightning fast data serialization\n* it uses [httpx](https://www.python-httpx.org) to provide both a sync and async api\n\n## Installation\n```console\npip install giphpy\n```\nor for poetry\n```console\npoetry add giphpy\n```\n\n## Help\nSee the [documentation](https://giphpy.readthedocs.io/en/latest/) for more details.\n\n## Example\n*giphpy* is extremely easy to use.  By setting `serialize=True`, you get a pydantic model returned to you instead of\na `httpx.Response` object.\n\nExample:\n\n```python\nimport giphpy\n\ngif = giphpy.gif_translate("spongebob", api_key="xxx", serialize=True)\nprint(gif)\n```\n\nThis will return a `GifResponse` object:\n```python\nGifResponse(\n        data=Gif(\n            type=\'gif\',\n            id=\'o6TTJ6ak4A97a\',\n            url=\'https://giphy.com/gifs/spongebob-squarepants-squidward-nose-o6TTJ6ak4A97a\',\n            slug=\'spongebob-squarepants-squidward-nose-o6TTJ6ak4A97a\',\n            bitly_gif_url=\'http://gph.is/YBiYub\',\n            bitly_url=\'http://gph.is/YBiYub\',\n            embed_url=\'https://giphy.com/embed/o6TTJ6ak4A97a\',\n            username=\'spongebob\',\n            source=\'\',\n            title=\'Nose GIF by SpongeBob SquarePants\',\n            rating=<Rating.g: \'g\'>,\n            content_url=\'\',\n            source_tld=\'\',\n            source_post_url=\'\',\n            is_sticker=False,\n            import_datetime=datetime.datetime(1970, 1, 1, 0, 0),\n            trending_datetime=datetime.datetime(2017, 12, 21, 16, 0, 1),\n            images=Images(\n                downsized=DownsizedImage(\n                    size=\'430185\',\n                    height=\'336\',\n                    width=\'500\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/giphy.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68\'\n                        \'p60zymuq6950uz&rid=giphy.gif&ct=g\'\n                    ),\n                ),\n                downsized_large=DownsizedLargeImage(\n                    size=\'430185\',\n                    height=\'336\',\n                    width=\'500\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/giphy.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68\'\n                        \'p60zymuq6950uz&rid=giphy.gif&ct=g\'\n                    ),\n                ),\n                downsized_medium=DownsizedMediumImage(\n                    size=\'430185\',\n                    height=\'336\',\n                    width=\'500\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/giphy.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68\'\n                        \'p60zymuq6950uz&rid=giphy.gif&ct=g\'\n                    ),\n                ),\n                downsized_small=DownsizedSmallImage(\n                    mp4_size=\'162356\',\n                    mp4=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/giphy-downsized-small.mp4?cid=9fbc9b3fgy0n3l2a9s\'\n                        \'mslyf34wgd2s5z68p60zymuq6950uz&rid=giphy-downsized-small.mp4&ct=g\'\n                    ),\n                    height=\'336\',\n                    width=\'500\',\n                ),\n                downsized_still=DownsizedStillImage(\n                    height=\'336\',\n                    width=\'500\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/giphy_s.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z\'\n                        \'68p60zymuq6950uz&rid=giphy_s.gif&ct=g\'\n                    ),\n                ),\n                fixed_height=FixedHeightImage(\n                    webp_size=\'112580\',\n                    webp=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200.webp?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68p\'\n                        \'60zymuq6950uz&rid=200.webp&ct=g\'\n                    ),\n                    mp4_size=\'36280\',\n                    mp4=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200.mp4?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68p6\'\n                        \'0zymuq6950uz&rid=200.mp4&ct=g\'\n                    ),\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68p6\'\n                        \'0zymuq6950uz&rid=200.gif&ct=g\'\n                    ),\n                    height=\'200\',\n                    width=\'298\',\n                    size=\'188398\',\n                ),\n                fixed_height_downsampled=FixedHeightDownsampledImage(\n                    webp_size=\'118418\',\n                    webp=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200_d.webp?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z6\'\n                        \'8p60zymuq6950uz&rid=200_d.webp&ct=g\'\n                    ),\n                    size=\'166021\',\n                    height=\'200\',\n                    width=\'298\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200_d.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68\'\n                        \'p60zymuq6950uz&rid=200_d.gif&ct=g\'\n                    ),\n                ),\n                fixed_height_small=FixedHeightSmallImage(\n                    webp_size=\'38138\',\n                    webp=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/100.webp?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68p\'\n                        \'60zymuq6950uz&rid=100.webp&ct=g\'\n                    ),\n                    mp4_size=\'12397\',\n                    mp4=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/100.mp4?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68p6\'\n                        \'0zymuq6950uz&rid=100.mp4&ct=g\'\n                    ),\n                    size=\'54532\',\n                    height=\'100\',\n                    width=\'149\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/100.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68p6\'\n                        \'0zymuq6950uz&rid=100.gif&ct=g\'\n                    ),\n                ),\n                fixed_height_small_still=FixedHeightSmallStillImage(\n                    height=\'100\',\n                    width=\'149\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/100_s.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68\'\n                        \'p60zymuq6950uz&rid=100_s.gif&ct=g\'\n                    ),\n                ),\n                fixed_height_still=FixedHeightStillImage(\n                    height=\'200\',\n                    width=\'298\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200_s.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68\'\n                        \'p60zymuq6950uz&rid=200_s.gif&ct=g\'\n                    ),\n                ),\n                fixed_width=FixedWidthImage(\n                    webp_size=\'61756\',\n                    webp=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200w.webp?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68\'\n                        \'p60zymuq6950uz&rid=200w.webp&ct=g\'\n                    ),\n                    mp4_size=\'19095\',\n                    mp4=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200w.mp4?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68p\'\n                        \'60zymuq6950uz&rid=200w.mp4&ct=g\'\n                    ),\n                    size=\'87701\',\n                    height=\'134\',\n                    width=\'200\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200w.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68p\'\n                        \'60zymuq6950uz&rid=200w.gif&ct=g\'\n                    ),\n                ),\n                fixed_width_downsampled=FixedWidthDownsampledImage(\n                    webp_size=\'62046\',\n                    webp=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200w_d.webp?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z\'\n                        \'68p60zymuq6950uz&rid=200w_d.webp&ct=g\'\n                    ),\n                    size=\'78853\',\n                    height=\'134\',\n                    width=\'200\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200w_d.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z6\'\n                        \'8p60zymuq6950uz&rid=200w_d.gif&ct=g\'\n                    ),\n                ),\n                fixed_width_small=FixedWidthSmallImage(\n                    webp_size=\'19028\',\n                    webp=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/100w.webp?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68\'\n                        \'p60zymuq6950uz&rid=100w.webp&ct=g\'\n                    ),\n                    mp4_size=\'7319\',\n                    mp4=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/100w.mp4?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68p\'\n                        \'60zymuq6950uz&rid=100w.mp4&ct=g\'\n                    ),\n                    size=\'25141\',\n                    height=\'67\',\n                    width=\'100\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/100w.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68p\'\n                        \'60zymuq6950uz&rid=100w.gif&ct=g\'\n                    ),\n                ),\n                fixed_width_small_still=FixedWidthSmallStillImage(\n                    height=\'67\',\n                    width=\'100\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/100w_s.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z6\'\n                        \'8p60zymuq6950uz&rid=100w_s.gif&ct=g\'\n                    ),\n                ),\n                fixed_width_still=FixedWidthStillImage(\n                    height=\'134\',\n                    width=\'200\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/200w_s.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z6\'\n                        \'8p60zymuq6950uz&rid=200w_s.gif&ct=g\'\n                    ),\n                ),\n                looping=LoopingImage(\n                    mp4=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/giphy-loop.mp4?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2\'\n                        \'s5z68p60zymuq6950uz&rid=giphy-loop.mp4&ct=g\'\n                    ),\n                ),\n                original_still=OriginalStillImage(\n                    height=\'336\',\n                    width=\'500\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/giphy_s.gif?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z\'\n                        \'68p60zymuq6950uz&rid=giphy_s.gif&ct=g\'\n                    ),\n                ),\n                original_mp4=OriginalMp4Image(\n                    mp4_size=\'123856\',\n                    mp4=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/giphy.mp4?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z68\'\n                        \'p60zymuq6950uz&rid=giphy.mp4&ct=g\'\n                    ),\n                    height=\'322\',\n                    width=\'480\',\n                ),\n                preview=PreviewImage(\n                    height=\'184\',\n                    width=\'273\',\n                    mp4_size=\'21235\',\n                    mp4=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/giphy-preview.mp4?cid=9fbc9b3fgy0n3l2a9smslyf34w\'\n                        \'gd2s5z68p60zymuq6950uz&rid=giphy-preview.mp4&ct=g\'\n                    ),\n                ),\n                preview_gif=PreviewGifImage(\n                    height=\'90\',\n                    width=\'134\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/giphy-preview.gif?cid=9fbc9b3fgy0n3l2a9smslyf34w\'\n                        \'gd2s5z68p60zymuq6950uz&rid=giphy-preview.gif&ct=g\'\n                    ),\n                ),\n                preview_webp=PreviewWebpImage(\n                    size=\'34118\',\n                    height=\'94\',\n                    width=\'140\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/giphy-preview.webp?cid=9fbc9b3fgy0n3l2a9smslyf34\'\n                        \'wgd2s5z68p60zymuq6950uz&rid=giphy-preview.webp&ct=g\'\n                    ),\n                ),\n                still_480w=Still480w(\n                    height=\'323\',\n                    width=\'480\',\n                    url=(\n                        \'https://media3.giphy.com/media/o6TTJ6ak4A97a/480w_s.jpg?cid=9fbc9b3fgy0n3l2a9smslyf34wgd2s5z6\'\n                        \'8p60zymuq6950uz&rid=480w_s.jpg&ct=g\'\n                    ),\n                    size=\'430185\',\n                ),\n            ),\n            user=User(\n                avatar_url=\'https://media2.giphy.com/avatars/spongebob/U4nimQFVGMqR.jpg\',\n                banner_image=\'\',\n                banner_url=\'\',\n                profile_url=\'https://giphy.com/spongebob/\',\n                username=\'spongebob\',\n                display_name=\'SpongeBob SquarePants\',\n                description=\'Who gifs in a pineapple under the sea?\',\n                instagram_url=\'\',\n                website_url=\'http://www.spongebob.com\',\n                is_verified=True,\n            ),\n            analytics_response_payload=None,\n            analytics=None,\n        ),\n        meta=Meta(\n            status=200,\n            msg=\'OK\',\n            response_id=\'gy0n3l2a9smslyf34wgd2s5z68p60zymuq6950uz\',\n        ),\n    )\n```\n',
    'author': 'Zach Schumacher',
    'author_email': 'zschu15@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<=3.10',
}


setup(**setup_kwargs)
